(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs/Observable'), require('rxjs/Subject'), require('rxjs/add/observable/zip'), require('rxjs/add/observable/from'), require('rxjs/add/operator/map'), require('rxjs/add/operator/switchMap'), require('rxjs/add/operator/take'), require('rxjs/add/operator/do'), require('rxjs/add/operator/filter'), require('rxjs/add/operator/delay'), require('rxjs/add/operator/skipWhile')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', 'rxjs/Observable', 'rxjs/Subject', 'rxjs/add/observable/zip', 'rxjs/add/observable/from', 'rxjs/add/operator/map', 'rxjs/add/operator/switchMap', 'rxjs/add/operator/take', 'rxjs/add/operator/do', 'rxjs/add/operator/filter', 'rxjs/add/operator/delay', 'rxjs/add/operator/skipWhile'], factory) :
	(factory((global.ng = global.ng || {}, global.ng.ngxHighlightjs = global.ng.ngxHighlightjs || {}),global.ng.core,global.Rx,global.Rx));
}(this, (function (exports,_angular_core,rxjs_Observable,rxjs_Subject) { 'use strict';

var HighlightService = (function () {
    /**
     * @param {?} options
     */
    function HighlightService(options) {
        var _this = this;
        this.options = {
            theme: 'github',
            path: 'assets/lib/hljs',
            auto: true
        };
        this.loadScript$ = new rxjs_Subject.Subject();
        this.highlighter$ = new rxjs_Subject.Subject();
        this.ready$ = new rxjs_Subject.Subject();
        this.options = Object.assign({}, this.options, options);
        /** Load hljs script and style only once */
        this.loadScript$
            .take(1)
            .do(function (renderer) {
            _this.renderer = renderer;
            _this.loadScript();
            _this.loadTheme();
        }).subscribe();
        /** highlight when script is ready */
        rxjs_Observable.Observable.zip(this.ready$, this.highlighter$, function (x, item) {
            /** highlight one item or many elements */
            var codeElements = [];
            switch (item.type) {
                case 'all':
                    codeElements = item.el.querySelectorAll('pre code');
                    break;
                case '':
                    codeElements = [item.el];
                    break;
                default:
                    codeElements = item.el.querySelectorAll(_this.highlight);
            }
            /** highlight all code elements */
            rxjs_Observable.Observable.from(codeElements)
                .filter(function (code) { return code.childNodes.length === 1 && code.childNodes[0].nodeName === '#text'; })
                .map(function (code) {
                /** Highlight only if content is a plain text */
                var highlightedCode = hljs.highlightAuto(code.innerText.trim()).value;
                /** Render the highlighted code */
                if (highlightedCode !== code.innerHTML) {
                    _this.renderer.setProperty(code, 'innerHTML', highlightedCode);
                }
            }).subscribe();
        }).subscribe();
    }
    /**
     * @param {?} renderer
     * @param {?} el
     * @param {?} type
     * @return {?}
     */
    HighlightService.prototype.highlight = function (renderer, el, type) {
        this.loadScript$.next(renderer);
        this.highlighter$.next({ el: el, type: type });
        if (isReady()) {
            this.ready$.next();
        }
    };
    /**
     * @return {?}
     */
    HighlightService.prototype.loadScript = function () {
        var _this = this;
        var /** @type {?} */ script = this.renderer.createElement('script');
        script.async = true;
        script.type = 'text/javascript';
        script.onload = function () {
            _this.ready$.next();
        };
        script.src = this.options.path + "/highlight.pack.js";
        this.renderer.setAttribute(script, 'data-timestamp', new Date().getTime().toString());
        this.renderer.appendChild(document.body, script);
    };
    /**
     * @return {?}
     */
    HighlightService.prototype.loadTheme = function () {
        var /** @type {?} */ style = this.renderer.createElement('link');
        style.rel = 'stylesheet';
        style.type = 'text/css';
        style.href = this.options.path + "/styles/" + this.options.theme + ".css";
        this.renderer.appendChild(document.body, style);
    };
    return HighlightService;
}());
HighlightService.decorators = [
    { type: _angular_core.Injectable },
];
/**
 * @nocollapse
 */
HighlightService.ctorParameters = function () { return [
    null,
]; };
/**
 * @return {?}
 */
function isReady() {
    return typeof hljs !== 'undefined';
}
var HighlightDirective = (function () {
    /**
     * @param {?} el
     * @param {?} renderer
     * @param {?} hl
     */
    function HighlightDirective(el, renderer, hl) {
        this.renderer = renderer;
        this.hl = hl;
        this.el = el.nativeElement;
    }
    /**
     * @return {?}
     */
    HighlightDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        this.hl.highlight(this.renderer, this.el, this.highlight);
        /** Auto highlight on changes */
        if (this.hl.options.auto) {
            this.domObs = new MutationObserver(function () { return _this.hl.highlight(_this.renderer, _this.el, _this.highlight); });
            this.domObs.observe(this.el, { childList: true, subtree: true });
        }
    };
    /**
     * @return {?}
     */
    HighlightDirective.prototype.ngOnDestroy = function () {
        if (this.hl.options.auto) {
            this.domObs.disconnect();
        }
    };
    return HighlightDirective;
}());
HighlightDirective.decorators = [
    { type: _angular_core.Directive, args: [{
                selector: '[highlight]'
            },] },
];
/**
 * @nocollapse
 */
HighlightDirective.ctorParameters = function () { return [
    { type: _angular_core.ElementRef, },
    { type: _angular_core.Renderer2, },
    { type: HighlightService, },
]; };
HighlightDirective.propDecorators = {
    'highlight': [{ type: _angular_core.Input },],
};
/**
 * @param {?} options
 * @return {?}
 */
function HighlightFactory(options) {
    return new HighlightService(options);
}
var OPTIONS = new _angular_core.InjectionToken('options');
var HighlightModule = (function () {
    function HighlightModule() {
    }
    /**
     * @param {?=} options
     * @return {?}
     */
    HighlightModule.forRoot = function (options) {
        return {
            ngModule: HighlightModule,
            providers: [
                { provide: OPTIONS, useValue: options },
                {
                    provide: HighlightService,
                    useFactory: HighlightFactory,
                    deps: [OPTIONS]
                }
            ]
        };
    };
    return HighlightModule;
}());
HighlightModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                declarations: [HighlightDirective],
                exports: [HighlightDirective]
            },] },
];
/**
 * @nocollapse
 */
HighlightModule.ctorParameters = function () { return []; };
var HighlightUmdDirective = (function () {
    /**
     * @param {?} el
     * @param {?} renderer
     */
    function HighlightUmdDirective(el, renderer) {
        this.renderer = renderer;
        this.highlighter$ = new rxjs_Subject.Subject();
        this.hlAuto = true;
        this.hlDelay = 200;
        this.el = el.nativeElement;
    }
    /**
     * @return {?}
     */
    HighlightUmdDirective.prototype.ngAfterViewInit = function () {
        var _this = this;
        var /** @type {?} */ codeElements = [];
        this.highlighter$
            .delay(this.hlDelay)
            .skipWhile(function () { return !isReady$1(); })
            .do(function () {
            switch (_this.highlight) {
                case 'all':
                    codeElements = _this.el.querySelectorAll('pre code');
                    break;
                case '':
                    codeElements = [_this.el];
                    break;
                default:
                    codeElements = _this.el.querySelectorAll(_this.highlight);
            }
            rxjs_Observable.Observable.from(codeElements)
                .take(1)
                .filter(function (code) { return (code.childNodes.length === 1 && code.childNodes[0].nodeName === '#text'); })
                .map(function (code) {
                /**
                 * Highlight only if content is a plain text
                 */
                var highlightedCode = hljs.highlightAuto(code.innerText.trim()).value;
                /** Render the highlighted code */
                if (highlightedCode !== code.innerHTML) {
                    _this.renderer.setProperty(code, 'innerHTML', highlightedCode);
                }
            }).subscribe();
        }).subscribe();
        this.highlighter$.next();
        /** Auto highlight on changes */
        if (this.hlAuto) {
            this.domObs = new MutationObserver(function () { return _this.highlighter$.next(); });
            this.domObs.observe(this.el, { childList: true, subtree: true });
        }
    };
    /**
     * @return {?}
     */
    HighlightUmdDirective.prototype.ngOnDestroy = function () {
        if (this.hlAuto) {
            this.domObs.disconnect();
        }
        this.highlighter$.unsubscribe();
    };
    return HighlightUmdDirective;
}());
HighlightUmdDirective.decorators = [
    { type: _angular_core.Directive, args: [{
                selector: '[highlight]'
            },] },
];
/**
 * @nocollapse
 */
HighlightUmdDirective.ctorParameters = function () { return [
    { type: _angular_core.ElementRef, },
    { type: _angular_core.Renderer2, },
]; };
HighlightUmdDirective.propDecorators = {
    'highlight': [{ type: _angular_core.Input },],
    'hlAuto': [{ type: _angular_core.Input },],
    'hlDelay': [{ type: _angular_core.Input },],
};
/**
 * @return {?}
 */
function isReady$1() {
    return typeof hljs !== 'undefined';
}
var HighlightUmdModule = (function () {
    function HighlightUmdModule() {
    }
    return HighlightUmdModule;
}());
HighlightUmdModule.decorators = [
    { type: _angular_core.NgModule, args: [{
                declarations: [HighlightUmdDirective],
                exports: [HighlightUmdDirective]
            },] },
];
/**
 * @nocollapse
 */
HighlightUmdModule.ctorParameters = function () { return []; };

exports.HighlightModule = HighlightModule;
exports.HighlightUmdModule = HighlightUmdModule;
exports.ɵe = HighlightUmdDirective;
exports.ɵc = HighlightDirective;
exports.ɵa = HighlightFactory;
exports.ɵb = OPTIONS;
exports.ɵd = HighlightService;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-highlightjs.umd.js.map
